@@ -1,5 +1,5 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%%% Copyright (c) 2012-2014 Kivra
+%%% Copyright (c) 2012-2015 Kivra
 %%%
 %%% Permission to use, copy, modify, and/or distribute this software for any
 %%% purpose with or without fee is hereby granted, provided that the above
@@ -39,7 +39,7 @@ generate(_Context) -> generate_fragment(?TOKEN_LENGTH).
 -spec generate_fragment(integer()) -> binary().
 generate_fragment(0) -> <<>>;
 generate_fragment(N) ->
-    Rand = base64:encode(rand_bytes(N)),
+    Rand = base64:encode(crypto:strong_rand_bytes(N)),
     Frag = << <<C>> || <<C>> <= <<Rand:N/bytes>>, is_alphanum(C) >>,
     <<Frag/binary, (generate_fragment(N - byte_size(Frag)))/binary>>.
 
@@ -50,11 +50,6 @@ is_alphanum(C) when C >= 16#41 andalso C =< 16#5A -> true;
 is_alphanum(C) when C >= 16#61 andalso C =< 16#7A -> true;
 is_alphanum(_)                                    -> false.
 
-%% @doc Generate N random bytes, using the crypto:strong_rand_bytes
--spec rand_bytes(non_neg_integer()) -> binary().
-rand_bytes(N) ->
-    crypto:strong_rand_bytes(N).
-
 %%%_* Tests ============================================================
 -ifdef(TEST).
 -include_lib("eunit/include/eunit.hrl").
